/*
	Chapter 4
	Comparing split times.
	Fits Poisson models with a different number of intervals and compares
	hazard ratios with Cox and exponential models.
	Also produces graph comparing the baseline hazard for the different
	Poisson models
	Includes figure 4.3
*/
version 11.0
set more off
clear

/* Fit Poisson models using varying number of splits */
use rott2
local j 1
foreach split of numlist 0.25 0.5 0.75 1 {
	preserve
	qui stsplit split_time, every(`split')	
	egen interval = group(split_time)
	gen risktime = _t - _t0
	collapse (min) start`j'=_t0 (max) end`j' = _t (count) n=_d (sum) ///
		risktime _d, by(interval recent)
	glm _d ibn.interval recent, family(poisson) ///
		lnoffset(risktime) nocons 
	estimates store  glm_`j' 
	predict h`j', nooffset mu
	replace h`j' = h`j'*1000
	drop if recent == 1
	keep start`j' end`i' h`j'
	save split`j', replace
	restore
	local j = `j' + 1
}
/* Cox and Exponential models */
qui stcox recent
estimates store cox
qui streg recent, dist(exp)
estimates store exp

/* Compare log hazard ratios and standard errors */
estimates table cox glm_1 glm_2 glm_3 glm_4 exp, ///
          keep(recent) equations(1) varwidth(8) ///
          b(%6.4fc) se(%6.4fc) modelwidth(8) 

// Figure 4.3
/* Plot baseline hazards */
use split1,clear 
merge using split2 split3 split4
local h1 "Interval Length: 0.25 Years"
local h2 "Interval Length: 0.5 Years"
local h3 "Interval Length: 0.75 Years"
local h4 "Interval Length: 1.0 Years"
forvalues i = 1/4 {
	twoway 	(pcspike h`i' start`i' h`i' end`i') ///
			, xtitle("") ///
			scheme(sj) ///
			ytitle("") ///
			title(`h`i'') yscale(range(0 200)) ///
			ylabel(0(50)200,angle(h)) ///
			name(g`i', replace)
}
graph combine g4 g3 g2 g1, nocopies ///
 			l1title("Recurrence rate (1000 PYs)") ///
			b1title(Years from surgery) ///
			scheme(sj)
set more on
