/*
	Chapter 4
	Using splines in Poisson models
	Sections 4.8.3 - 4.8.6
	Includes figures 4.6, 4.7, 4.8, 4.9, 4.10, 4.11
	
*/
version 11.0
set more off
clear

/* Load data and stset */
use rott2
stsplit split_time, every(`=1/12')
gen risktime = _t - _t0
collapse (min) start=_t0 (max) end = _t (count) n=_d (sum) risktime _d, ///
    by(split_time recent)

/* generate splines and fit poisson model */	
gen midt = (start + end)/2
rcsgen midt, df(4) gen(t_rcs) fw(_d) orthog
local knots `r(knots)'

glm _d t_rcs1-t_rcs4 recent, family(poisson) lnoffset(risktime) ///
	nolog noheader

/* predict hazard */	
gen lh1 = -2.485 -0.259*t_rcs1 + 0.012*t_rcs2 - 0.246*t_rcs3 + 0.014*t_rcs4

predict lh2, xb nooffset
predict lh2_se, stdp
gen h = exp(lh2)*1000
gen h_lci = exp(lh2 - 1.96*lh2_se)*1000
gen h_uci = exp(lh2 + 1.96*lh2_se)*1000

// Figure 4.6
/* Graph of hazard functions */
twoway	(line h midt if recent == 0, sort lpattern(solid)) ///
		(line h midt if recent == 1, sort lpattern(longdash)) ///
		,xline(`knots', lpattern(shortdash) lwidth(thin)) scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(50(50)200,angle(horizontal) format(%3.0f)) yscale(log) ///
		legend(order(1 "1978-1987" 2 "1988-1993") ring(0) col(1) pos(1))	

// Figure 4.7
/* Baseline hazard with 95% CI */		
twoway	(rarea h_lci h_uci midt if recent ==0, sort pstyle(ci)) ///
		(line h midt if recent == 0, sort lpattern(solid)) ///
		,xline(`knots', lpattern(shortdash) lwidth(thin)) scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(50(50)200,angle(horizontal) format(%3.0f)) yscale(log) ///
		legend(off) 

// Figure 4.8
/* Compare different number of knots for baseline hazard */		
forvalues i = 2 / 8 {
    rcsgen midt, df(`i') gen(t`i'_rcs) fw(_d) orthog
    glm _d t`i'_rcs* recent, family(poisson) lnoffset(risktime) nolog noheader
    estimates store df`i'
    estat ic, n(1477) 
    local AIC`i': display %6.1f `= el(r(S),1,5)'
    local BIC`i': display %6.1f `= el(r(S),1,6)'
    predict h_df`i', mu nooffset
    replace h_df`i' = h_df`i'*1000
    local legend `legend' `=`i'-1' `"`i' df: AIC =  `AIC`i'', BIC = `BIC`i''"'
}
twoway	(line h_df* midt if recent == 0, sort) ///
        , scheme(sj) ///
        xtitle("Years from aurgery") ///
        ytitle("Recurrence rate (per 1000 PYs)") ///
        ylabel(0(50)200,angle(horizontal) format(%3.0f)) ///
        legend(order(`legend') ring(0) col(1) pos(1) size(*1))		

estimates table df*, keep(recent) b(%4.3f) se(%5.4f) varw(6)

// Figure 4.9
/* Compare knots for spline functions of ln(t) */
gen lnt = ln(midt)
forvalues i = 2 / 8 {
    rcsgen lnt, df(`i') gen(lnt`i'_rcs) fw(_d) orthog
    glm _d lnt`i'_rcs* recent, family(poisson) lnoffset(risktime) nolog noheader
    estimates store ln_df`i'
    estat ic, n(1477) 
    local AIC`i': display %6.1f `= el(r(S),1,5)'
    local BIC`i': display %6.1f `= el(r(S),1,6)'	
    predict h_ln_df`i', mu nooffset
    replace h_ln_df`i' = h_ln_df`i'*1000
    local ln_legend `ln_legend' `=`i'-1' `"`i' df: AIC =  `AIC`i'', BIC = `BIC`i''"'
}
twoway	(line h_ln_df* midt if recent == 0, sort) ///
        , scheme(sj) ///
        xtitle("Years from surgery") ///
        ytitle("Recurrence rate (per 1000 PYs)") ///
        ylabel(0(50)200,angle(horizontal) format(%3.0f)) ///
        legend(order(`ln_legend') ring(0) col(1) pos(1) size(*1))		

estimates table ln_df*, keep(recent) b(%4.3f) se(%5.4f) varw(6)

// Figure 4.10
/* Random knots */
forvalues i = 1 / 10 {
    local p1 = 0 + int(runiform()* 6)
    local p2 = 6 + int(runiform()*20)
    local p3 = 26 + int(runiform()*25)
    local p4 = 51 + int(runiform()*25)
    local p5 = 76 + int(runiform()*20)
    local p6 = 96 + int(runiform()*5)
    rcsgen lnt, p(`p1' `p2' `p3' `p4' `p5' `p6') gen(trnd`i'_rcs) ///
          orthog fw(_d)
    glm _d trnd`i'_rcs* recent, family(poisson) lnoffset(risktime) 
    predict h_rnd`i', mu nooffset
    replace h_rnd`i' = h_rnd`i'*1000
}
twoway	(line h_rnd* midt if recent == 0, sort) ///
		, scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(0(50)200,angle(horizontal) format(%3.0f)) ///
		legend(off)		

/* refit original spline model and predict survival function */
/* do not orthogonlize spline variables */
drop t_rcs*
rcsgen midt, df(4) gen(t_rcs) fw(_d) 
local knots `r(knots)'
		
glm _d t_rcs1-t_rcs4 recent, family(poisson) lnoffset(risktime) ///
	nolog noheader
preserve
drop _all
range plottime 0 5 200
rcsgen plottime, knots(`knots') gen(t_rcs)
mata
X = st_data((1,200),("t_rcs1", "t_rcs2", "t_rcs3", "t_rcs4"))
X = X,J(200,1,0),J(200,1,1)
V = st_matrix("e(V)")
b = st_matrix("e(b)")'
h = exp(X*b)
L = lowertriangle(J(200,200,5/200),5/200)
ch = L*exp(X*b)
var_ch = L*(diag(h)*(b'*V*b)*diag(h)')*L'
st_store(.,st_addvar("double","predsurv"),exp(-ch))
st_store(.,st_addvar("double","predsurv_uci"),exp(-ch - sqrt(diagonal(var_ch))))
st_store(.,st_addvar("double","predsurv_lci"),exp(-ch + sqrt(diagonal(var_ch))))
end

// Figure 4.11
twoway 	(rarea predsurv_lci predsurv_uci plottime, pstyle(ci)) ///
			(line predsurv plottime, lpattern(solid)) , ///
			legend(off) ///
			xtitle("Years from surgery") ///
			ytitle("Survival") ///
			ylabel(0(0.2)1,angle(h) format(%3.1f)) 
restore
set more on
