/*
	Chapter 8
	Breast cancer model selection
	Includes figures 8.13, 8.14, 8.15, 8.16, 8.17, 8.18
*/	
set more off
clear all
set memory 500m
use ew_breast_ch8

stset survtime, failure(dead==1) exit(time 5) id(ident)
gen age = int(min(agediag + _t,99))
gen year = int(year(datediag) + _t)
merge m:1 sex region dep year age using popmort_uk, keepusing(rate) keep(match)

/* Define models for sensitivity analysis */
local model1 df(3) dftvc(3) tvc(agegrp2-agegrp5)
local model2 df(5) dftvc(3) tvc(agegrp2-agegrp5)
local model3 df(5) dftvc(5) tvc(agegrp2-agegrp5)
local model4 df(7) dftvc(3) tvc(agegrp2-agegrp5)
local model5 df(7) dftvc(5) tvc(agegrp2-agegrp5)
local model6 df(7) dftvc(7) tvc(agegrp2-agegrp5)
local model7 df(9) dftvc(3) tvc(agegrp2-agegrp5)
local model8 df(9) dftvc(5) tvc(agegrp2-agegrp5)
local model9 df(9) dftvc(7) tvc(agegrp2-agegrp5)
local model10 df(9) dftvc(9) tvc(agegrp2-agegrp5)
forvalues i = 1/10 {
	stpm2 agegrp2-agegrp5, scale(hazard) `model`i'' bhazard(rate) nolog
	estimates store model`i'
	predict eh0_m`i', hazard zeros per(1000)
	predict rs0_m`i', survival zeros
	predict ehr5_m`i', hrnum(agegrp5 1) ci
	predict ehdiff5_m`i', hdiff1(agegrp5 1) per(1000) ci
	predict rsdiff5_m`i', sdiff1(agegrp5 1) ci
}

qui count if _d == 1
estimates stats model*, n(`r(N)')

// Figure 8.13
/* Compare excess mortality rates */
twoway	(line eh0_m1 _t, sort lpattern(solid) lcolor(gs1) lwidth(thick)) ///
		(line eh0_m2 _t, sort lpattern(solid) lcolor(gs2)) ///
		(line eh0_m3 _t, sort lpattern(solid) lcolor(gs3)) ///
		(line eh0_m4 _t, sort lpattern(solid) lcolor(gs4)) ///
		(line eh0_m5 _t, sort lpattern(solid) lcolor(gs5)) ///
		(line eh0_m6 _t, sort lpattern(solid) lcolor(gs6)) ///
		(line eh0_m7 _t, sort lpattern(solid) lcolor(gs7)) ///
		(line eh0_m8 _t, sort lpattern(solid) lcolor(gs8)) ///
		(line eh0_m9 _t, sort lpattern(solid) lcolor(gs9)) ///
		(line eh0_m10 _t, sort lpattern(solid) lcolor(gs10)) ///
		,  yscale(log) ///
		ylabel(40 50 75 100 , angle(h) format(%4.0f)) ///
		ytitle("Excess mortality rate (per 1000 PYs)") ///
		xtitle("Years from diagnosis") ///
		legend(order(1 "Model 1" 2 "Model 2" 3 "Model 3" 4 "Model 4" 5 "Model 5" 6 "Model 6" 7 "Model 7" ///
					8 "Model 8" 9 "Model 9" 10 "Model 10") ///
				ring(0) pos(5) cols(3))

// Figure 8.14
/* compare relative survival */
twoway	(line rs0_m1 _t, sort lpattern(solid) lcolor(gs1) lwidth(thick)) ///
		(line rs0_m2 _t, sort lpattern(solid) lcolor(gs2)) ///
		(line rs0_m3 _t, sort lpattern(solid) lcolor(gs3)) ///
		(line rs0_m4 _t, sort lpattern(solid) lcolor(gs4)) ///
		(line rs0_m5 _t, sort lpattern(solid) lcolor(gs5)) ///
		(line rs0_m6 _t, sort lpattern(solid) lcolor(gs6)) ///
		(line rs0_m7 _t, sort lpattern(solid) lcolor(gs7)) ///
		(line rs0_m8 _t, sort lpattern(solid) lcolor(gs8)) ///
		(line rs0_m9 _t, sort lpattern(solid) lcolor(gs9)) ///
		(line rs0_m10 _t, sort lpattern(solid) lcolor(gs10)) ///
		, ylabel(0(0.2)1 , angle(h) format(%3.1f)) ///
		ytitle("Relative survival") ///
		xtitle("Years from diagnosis") ///
		legend(order(1 "Model 1" 2 "Model 2" 3 "Model 3" 4 "Model 4" 5 "Model 5" 6 "Model 6" 7 "Model 7" ///
					8 "Model 8" 9 "Model 9" 10 "Model 10") ///
				ring(0) pos(5) cols(3))
			
// Figure 8.15
/* compare excess hazard ratios */			
twoway	(line ehr5_m1 _t, sort lpattern(solid) lcolor(gs1) lwidth(thick)) ///
		(line ehr5_m2 _t, sort lpattern(solid) lcolor(gs2)) ///
		(line ehr5_m3 _t, sort lpattern(solid) lcolor(gs3)) ///
		(line ehr5_m4 _t, sort lpattern(solid) lcolor(gs4)) ///
		(line ehr5_m5 _t, sort lpattern(solid) lcolor(gs5)) ///
		(line ehr5_m6 _t, sort lpattern(solid) lcolor(gs6)) ///
		(line ehr5_m7 _t, sort lpattern(solid) lcolor(gs7)) ///
		(line ehr5_m8 _t, sort lpattern(solid) lcolor(gs8)) ///
		(line ehr5_m9 _t, sort lpattern(solid) lcolor(gs9)) ///
		(line ehr5_m10 _t, sort lpattern(solid) lcolor(gs10)) ///
		, yscale(log) ylabel( 1 2 4 10 20 30 50, angle(h) format(%3.1f)) ///
		ytitle("Excess mortality-rate ratio") ///
		xtitle("Years from diagnosis") ///
		legend(order(1 "Model 1" 2 "Model 2" 3 "Model 3" 4 "Model 4" 5 "Model 5" 6 "Model 6" 7 "Model 7" ///
					8 "Model 8" 9 "Model 9" 10 "Model 10") ///
				ring(0) pos(1) cols(3))

// Figure 8.16
/* Time dependent effect of age for selected models */
foreach i in 7 8 9 10 {
twoway	(rarea ehr5_m`i'_lci ehr5_m`i'_uci _t, sort pstyle(ci)) ///
		(line ehr5_m`i' _t, sort lpattern(solid) lwidth(medthick)) ///
		, yscale(log) ylabel( 1 2 4 10 20 30 50, angle(h) format(%3.1f)) ///
		ytitle("Excess mortality-rate ratio") ///
		xtitle("Years from diagnosis") ///
		legend(off) ///
		title("Model `i'") ///
		name(mod_`i',replace)  nodraw
}
graph combine mod_7 mod_8 mod_9 mod_10, nocopies

// Figure 8.17
/* compare excess mortality rates differences */
twoway	(line ehdiff5_m1 _t, sort lpattern(solid) lcolor(gs1) lwidth(thick)) ///
		(line ehdiff5_m2 _t, sort lpattern(solid) lcolor(gs2)) ///
		(line ehdiff5_m3 _t, sort lpattern(solid) lcolor(gs3)) ///
		(line ehdiff5_m4 _t, sort lpattern(solid) lcolor(gs4)) ///
		(line ehdiff5_m5 _t, sort lpattern(solid) lcolor(gs5)) ///
		(line ehdiff5_m6 _t, sort lpattern(solid) lcolor(gs6)) ///
		(line ehdiff5_m7 _t, sort lpattern(solid) lcolor(gs7)) ///
		(line ehdiff5_m8 _t, sort lpattern(solid) lcolor(gs8)) ///
		(line ehdiff5_m9 _t, sort lpattern(solid) lcolor(gs9)) ///
		(line ehdiff5_m10 _t, sort lpattern(solid) lcolor(gs10)) ///
		, yscale(log) ylabel(10 50 100 200 400 1000 2000, angle(h) format(%3.0f)) ///
		ytitle("Excess mortality-rate difference") ///
		xtitle("Years from diagnosis") ///
		legend(order(1 "Model 1" 2 "Model 2" 3 "Model 3" 4 "Model 4" 5 "Model 5" 6 "Model 6" 7 "Model 7" ///
					8 "Model 8" 9 "Model 9" 10 "Model 10") ///
				ring(0) pos(1) cols(3))

// Figure 8.18
/* Compare relative survival differences */				
twoway	(line rsdiff5_m1 _t, sort lpattern(solid) lcolor(gs1) lwidth(thick)) ///
		(line rsdiff5_m2 _t, sort lpattern(solid) lcolor(gs2)) ///
		(line rsdiff5_m3 _t, sort lpattern(solid) lcolor(gs3)) ///
		(line rsdiff5_m4 _t, sort lpattern(solid) lcolor(gs4)) ///
		(line rsdiff5_m5 _t, sort lpattern(solid) lcolor(gs5)) ///
		(line rsdiff5_m6 _t, sort lpattern(solid) lcolor(gs6)) ///
		(line rsdiff5_m7 _t, sort lpattern(solid) lcolor(gs7)) ///
		(line rsdiff5_m8 _t, sort lpattern(solid) lcolor(gs8)) ///
		(line rsdiff5_m9 _t, sort lpattern(solid) lcolor(gs9)) ///
		(line rsdiff5_m10 _t, sort lpattern(solid) lcolor(gs10)) ///
		,  ylabel(, angle(h) format(%9.2f)) ///
		ytitle("Relative survival difference") ///
		xtitle("Years from diagnosis") ///
		legend(order(1 "Model 1" 2 "Model 2" 3 "Model 3" 4 "Model 4" 5 "Model 5" 6 "Model 6" 7 "Model 7" ///
					8 "Model 8" 9 "Model 9" 10 "Model 10") ///
				ring(0) pos(1) cols(3))
set more on
