/*
	Chapter 8
	Relative survival models using stpm2
*/
version 11.0
set scheme sj
set more off
clear

/* Load data and merge in expected mortality rates */	
use ew_breast_ch8

stset survtime, failure(dead==1) exit(time 5) id(ident)
gen age = int(min(agediag + _t,99))
gen year = int(year(datediag) + _t)
merge m:1 sex region dep year age using popmort_UK ///
	,keepusing(rate) keep(match)

/* Proportional excess hazards model */	
stpm2 agegrp2-agegrp5, scale(hazard) df(7) eform bhazard(rate) nolog
estimates store rs_hazard

/* predict excess hazard rates */
range temptime 0.003 5 200
predict eh_ph1, hazard per(1000) zeros timevar(temptime)
forvalues i = 2/5 {
	predict eh_ph`i', hazard per(1000) at(agegrp`i' 1) ///
		timevar(temptime) zeros
}

// Figure 8.6
twoway	(line eh_ph1 temptime, sort lpattern(solid)) ///
		(line eh_ph2 temptime, sort lpattern(longdash)) ///
		(line eh_ph3 temptime, sort lpattern(dash)) ///
		(line eh_ph4 temptime, sort lpattern(shortdash)) ///
		(line eh_ph5 temptime, sort lpattern(dot)) ///
		,  yscale(log) ///
		ylabel(50 100 200 500 750 1000 1500, angle(h) format(%4.0f)) ///
		ytitle("Excess Mortality Rate (per 1000 person years)") ///
		xtitle("Years from Diagnosis") ///
		legend(order(1 "<50" 2 "50-59" 3 "60-69" 4 "70-79" 5 "80+") ring(0) pos(1) cols(1))

/* proportional odds model */
stpm2 agegrp2-agegrp5, scale(odds) df(7) eform bhazard(rate) nolog
estimates store rs_odds
predict ehr5_po, hrnum(agegrp5 1) timevar(temptime) ci

estimates stats rs_hazard rs_odds, n(47692)

/* Using the scale(theta) option */
stpm2 agegrp2-agegrp5, scale(theta) df(7) bhazard(rate) nolog
estimates store rs_theta
predict ehr5_theta, hrnum(agegrp5 1) timevar(temptime) ci
estimates stats rs_hazard rs_odds rs_theta, n(47692)
	
// Figure 8.7
/* Compare time-dependent excess hazard ratios */
twoway	(rarea ehr5_po_lci ehr5_po_uci temptime, sort pstyle(ci)) ///
		(rarea ehr5_theta_lci ehr5_theta_uci temptime, sort pstyle(ci)) ///
		(line ehr5_po temptime, sort lpattern(solid)) ///
		(line ehr5_theta temptime, sort lpattern(dash)) ///
		,  yscale(log) ///
		ylabel(1 2 5 10 20, angle(h) format(%3.0f)) ///
		ytitle("Excess Mortality Ratio") ///
		xtitle("Years from Diagnosis") ///
		yline(2.65, lpattern(dash)) ///
		legend(order(2 "Proportional Odds" 3 "Theta Model") ring(0) pos(1) cols(1))

/* Model with time-dependent effect of age group */
stpm2 agegrp2-agegrp5, scale(hazard) df(7) bhazard(rate) ///
	tvc(agegrp2-agegrp5) dftvc(3) nolog

predict eh_tvc1, hazard per(1000) timevar(temptime) zeros
predict rs_tvc1, survival timevar(temptime) zeros
forvalues i = 2/5 {
	predict eh_tvc`i', hazard per(1000) at(agegrp`i' 1) ///
		timevar(temptime) zeros
	predict rs_tvc`i', survival at(agegrp`i' 1) ///
		timevar(temptime) zeros
}
forvalues i = 2/5 {
	predict ehr`i'_tvc, hrnum(agegrp`i' 1) timevar(temptime) ci
	predict ehdiff`i'_tvc, hdiff1(agegrp`i' 1) timevar(temptime) per(1000) ci
	predict rsdiff`i'_tvc, sdiff1(agegrp`i' 1) timevar(temptime) ci
}

// Figure 8.8
/* plot of excess mortality rates */
twoway	(line eh_tvc1 temptime, sort lpattern(solid)) ///
		(line eh_tvc2 temptime, sort lpattern(longdash)) ///
		(line eh_tvc3 temptime, sort lpattern(dash)) ///
		(line eh_tvc4 temptime, sort lpattern(shortdash)) ///
		(line eh_tvc5 temptime, sort lpattern(dot)) ///
		,  yscale(log) ///
		ylabel(50 100 200 500 750 1000 1500, angle(h) format(%4.0f)) ///
		ytitle("Excess Mortality Rate (per 1000 person years)") ///
		xtitle("Years from Diagnosis") ///
		legend(order(1 "<50" 2 "50-59" 3 "60-69" 4 "70-79" 5 "80+") ring(0) pos(1) cols(1))

// Figure 8.9
/* Time-dependent excess hazard ratios */
local title2 "50-59"
local title3 "60-69"
local title4 "70-79"
local title5 "80+"
forvalues i = 2/5 {
	twoway	(rarea ehr`i'_tvc_lci ehr`i'_tvc_uci temptime, sort pstyle(ci)) ///
			(line ehr`i'_tvc temptime, sort lpattern(solid)) ///
			,  yscale(log) ///
			ylabel(1 2 4 10 20 30 50, angle(h) format(%3.0f)) ///
			ytitle("Excess Mortality Rate Ratio") ///
			xtitle("Years from Diagnosis") ///
			legend(off) name(ehr`i',replace) ///
			yline(1, lpattern(dash) lwidth(thin)) ///
			title("`title`i''") nodraw
}
graph combine ehr2 ehr4 ehr4 ehr5, nocopies

/* Difference in excess mortality rates */
local title2 "50-59"
local title3 "60-69"
local title4 "70-79"
local title5 "80+"
local if4 if temptime>0.08333
local if5 if temptime>0.08333

// Figure 8.10
forvalues i = 2/5 {
	twoway	(rarea ehdiff`i'_tvc_lci ehdiff`i'_tvc_uci temptime `if`i'', sort pstyle(ci)) ///
			(line ehdiff`i'_tvc temptime `if`i'', sort lpattern(solid)) ///
			, ylabel(, angle(h) format(%5.0f)) ///
			ytitle("Difference in Excess Mortality Rates" "(per 1000 person years)",size(*0.8)) ///
			xtitle("Years from Diagnosis") ///
			legend(off) name(ehdiff`i',replace) ///
			yline(0, lpattern(dash) lwidth(thin)) ///
			title("`title`i''") nodraw 
}
graph combine ehdiff2 ehdiff4 ehdiff4 ehdiff5, nocopies ycommon ///
			note("Due to very high initial differences, the estimated functions for the 70-79 and" ///
			"80+ age groups are not plotted for the first month.")

drop _merge
merge 1:1 _n using breast_rs_lifetable

// Figure 8.11
/* Predicted relative survival by age group */
twoway	(line rs_tvc1 temptime, sort lpattern(solid)) ///
		(line rs_tvc2 temptime, sort lpattern(longdash)) ///
		(line rs_tvc3 temptime, sort lpattern(dash)) ///
		(line rs_tvc4 temptime, sort lpattern(shortdash)) ///
		(line rs_tvc5 temptime, sort lpattern(dot)) ///
		(scatter cr_e2 end_e2, symbol(o) mcolor(black)) ///
		,  ylabel(0(0.2)1, angle(h) format(%3.1f)) ///
		ytitle("Relative Survival") ///
		xtitle("Years from Diagnosis") ///
		legend(order(1 "<50" 2 "50-59" 3 "60-69" 4 "70-79" 5 "80+") ring(0) pos(5) cols(1))

// Figure 8.12
/* Difference in relative survival */
local title2 "50-59"
local title3 "60-69"
local title4 "70-79"
local title5 "80+"
forvalues i = 2/5 {
	twoway	(rarea rsdiff`i'_tvc_lci rsdiff`i'_tvc_uci temptime, sort pstyle(ci)) ///
			(line rsdiff`i'_tvc temptime, sort lpattern(solid)) ///
			, ylabel(, angle(h) format(%3.2f)) ///
			ytitle("Difference in Relative Survival") ///
			xtitle("Years from Diagnosis") ///
			legend(off) name(rsdiff`i',replace) ///
			yline(0, lpattern(dash) lwidth(thin)) ///
			title("`title`i''") nodraw
}
graph combine rsdiff2 rsdiff3 rsdiff4 rsdiff5, nocopies ycommon
set more on
